Extent2DBuilder

Struct Extent2DBuilder 

pub struct Extent2DBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> Extent2DBuilder<'a>

pub fn width(self, width: u32) -> Extent2DBuilder<'a>

pub fn height(self, height: u32) -> Extent2DBuilder<'a>

pub fn build(self) -> Extent2D

Calling build will discard all the lifetime information. Only call this if necessary! Builders implement Deref targeting their corresponding Vulkan struct, so references to builders can be passed directly to Vulkan functions.