pub struct ImageLayout(/* private fields */);Expand description
Implementations
Sourceimpl ImageLayout
impl ImageLayout
Sourceimpl ImageLayout
impl ImageLayout
Sourcepub const UNDEFINED: ImageLayout
pub const UNDEFINED: ImageLayout
Implicit layout an image is when its contents are undefined due to various reasons (e.g. right after creation)
Sourcepub const GENERAL: ImageLayout
pub const GENERAL: ImageLayout
General layout when image can be used for any kind of access
Sourcepub const COLOR_ATTACHMENT_OPTIMAL: ImageLayout
pub const COLOR_ATTACHMENT_OPTIMAL: ImageLayout
Optimal layout when image is only used for color attachment read/write
Sourcepub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
pub const DEPTH_STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
Optimal layout when image is only used for depth/stencil attachment read/write
Sourcepub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: ImageLayout
pub const DEPTH_STENCIL_READ_ONLY_OPTIMAL: ImageLayout
Optimal layout when image is used for read only depth/stencil attachment and shader access
Sourcepub const SHADER_READ_ONLY_OPTIMAL: ImageLayout
pub const SHADER_READ_ONLY_OPTIMAL: ImageLayout
Optimal layout when image is used for read only shader access
Sourcepub const TRANSFER_SRC_OPTIMAL: ImageLayout
pub const TRANSFER_SRC_OPTIMAL: ImageLayout
Optimal layout when image is used only as source of transfer operations
Sourcepub const TRANSFER_DST_OPTIMAL: ImageLayout
pub const TRANSFER_DST_OPTIMAL: ImageLayout
Optimal layout when image is used only as destination of transfer operations
Sourcepub const PREINITIALIZED: ImageLayout
pub const PREINITIALIZED: ImageLayout
Initial layout used when the data is populated by the CPU
Sourceimpl ImageLayout
Generated from ‘VK_KHR_swapchain’
impl ImageLayout
Generated from ‘VK_KHR_swapchain’
pub const PRESENT_SRC_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
pub const VIDEO_DECODE_DST_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
pub const VIDEO_DECODE_SRC_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_decode_queue’
pub const VIDEO_DECODE_DPB_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_shared_presentable_image’
impl ImageLayout
Generated from ‘VK_KHR_shared_presentable_image’
pub const SHARED_PRESENT_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_maintenance2’
impl ImageLayout
Generated from ‘VK_KHR_maintenance2’
pub const DEPTH_READ_ONLY_STENCIL_ATTACHMENT_OPTIMAL_KHR: ImageLayout = Self::DEPTH_READ_ONLY_STENCIL_ATTACHMENT_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_KHR_maintenance2’
impl ImageLayout
Generated from ‘VK_KHR_maintenance2’
pub const DEPTH_ATTACHMENT_STENCIL_READ_ONLY_OPTIMAL_KHR: ImageLayout = Self::DEPTH_ATTACHMENT_STENCIL_READ_ONLY_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_NV_shading_rate_image’
impl ImageLayout
Generated from ‘VK_NV_shading_rate_image’
pub const SHADING_RATE_OPTIMAL_NV: ImageLayout = Self::FRAGMENT_SHADING_RATE_ATTACHMENT_OPTIMAL_KHR
Sourceimpl ImageLayout
Generated from ‘VK_EXT_fragment_density_map’
impl ImageLayout
Generated from ‘VK_EXT_fragment_density_map’
Sourceimpl ImageLayout
Generated from ‘VK_KHR_fragment_shading_rate’
impl ImageLayout
Generated from ‘VK_KHR_fragment_shading_rate’
Sourceimpl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
impl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
pub const DEPTH_ATTACHMENT_OPTIMAL_KHR: ImageLayout = Self::DEPTH_ATTACHMENT_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
impl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
pub const DEPTH_READ_ONLY_OPTIMAL_KHR: ImageLayout = Self::DEPTH_READ_ONLY_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
impl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
pub const STENCIL_ATTACHMENT_OPTIMAL_KHR: ImageLayout = Self::STENCIL_ATTACHMENT_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
impl ImageLayout
Generated from ‘VK_KHR_separate_depth_stencil_layouts’
pub const STENCIL_READ_ONLY_OPTIMAL_KHR: ImageLayout = Self::STENCIL_READ_ONLY_OPTIMAL
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
pub const VIDEO_ENCODE_DST_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
pub const VIDEO_ENCODE_SRC_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
impl ImageLayout
Generated from ‘VK_KHR_video_encode_queue’
pub const VIDEO_ENCODE_DPB_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_synchronization2’
impl ImageLayout
Generated from ‘VK_KHR_synchronization2’
pub const READ_ONLY_OPTIMAL_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_KHR_synchronization2’
impl ImageLayout
Generated from ‘VK_KHR_synchronization2’
pub const ATTACHMENT_OPTIMAL_KHR: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_1’
impl ImageLayout
Generated from ‘VK_VERSION_1_1’
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_1’
impl ImageLayout
Generated from ‘VK_VERSION_1_1’
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_2’
impl ImageLayout
Generated from ‘VK_VERSION_1_2’
pub const DEPTH_ATTACHMENT_OPTIMAL: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_2’
impl ImageLayout
Generated from ‘VK_VERSION_1_2’
pub const DEPTH_READ_ONLY_OPTIMAL: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_2’
impl ImageLayout
Generated from ‘VK_VERSION_1_2’
pub const STENCIL_ATTACHMENT_OPTIMAL: ImageLayout
Sourceimpl ImageLayout
Generated from ‘VK_VERSION_1_2’
impl ImageLayout
Generated from ‘VK_VERSION_1_2’
pub const STENCIL_READ_ONLY_OPTIMAL: ImageLayout