QueryPoolCreateInfoBuilder

Struct QueryPoolCreateInfoBuilder 

pub struct QueryPoolCreateInfoBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> QueryPoolCreateInfoBuilder<'a>

pub fn flags( self, flags: QueryPoolCreateFlags, ) -> QueryPoolCreateInfoBuilder<'a>

pub fn query_type(self, query_type: QueryType) -> QueryPoolCreateInfoBuilder<'a>

pub fn query_count(self, query_count: u32) -> QueryPoolCreateInfoBuilder<'a>

pub fn pipeline_statistics( self, pipeline_statistics: QueryPipelineStatisticFlags, ) -> QueryPoolCreateInfoBuilder<'a>

pub fn push_next<T>(self, next: &'a mut T) -> QueryPoolCreateInfoBuilder<'a>

Prepends the given extension struct between the root and the first pointer. This method only exists on structs that can be passed to a function directly. Only valid extension structs can be pushed into the chain. If the chain looks like A -> B -> C, and you call builder.push_next(&mut D), then the chain will look like A -> D -> B -> C.

pub fn build(self) -> QueryPoolCreateInfo

Calling build will discard all the lifetime information. Only call this if necessary! Builders implement Deref targeting their corresponding Vulkan struct, so references to builders can be passed directly to Vulkan functions.